@@ -2,24 +2,17 @@
 
 import functools
 import inspect
-import json
 import os
 import sys
-from io import open
 from types import MethodType
 from typing import Any, Callable, Dict, Iterable, List, Optional, Tuple, Type, Union
 
-import requests
 import six
 
-try:
-    from lark import ParseError
-except ImportError:
-    from lark.common import ParseError
-
-from brewtils.choices import parse
+from brewtils.choices import process_choices
+from brewtils.display import resolve_form, resolve_schema, resolve_template
 from brewtils.errors import PluginParamError, _deprecate
-from brewtils.models import Command, Parameter, Choices
+from brewtils.models import Command, Parameter, Resolvable
 
 if sys.version_info.major == 2:
     from funcsigs import signature, Parameter as InspectParameter  # noqa
@@ -92,6 +85,7 @@ def command(
     template=None,  # type: Optional[str]
     icon_name=None,  # type: Optional[str]
     hidden=False,  # type: Optional[bool]
+    metadata=None,  # type: Optional[Dict]
 ):
     """Decorator for specifying Command details
 
@@ -119,6 +113,7 @@ def command(
         template: A custom template definition.
         icon_name: The icon name. Should be either a FontAwesome or a Glyphicon name.
         hidden: Flag controlling whether the command is visible on the user interface.
+        metadata: Free-form dictionary
 
     Returns:
         The decorated function
@@ -135,6 +130,7 @@ def command(
             template=template,
             icon_name=icon_name,
             hidden=hidden,
+            metadata=metadata,
         )
 
     new_command = Command(
@@ -147,6 +143,7 @@ def command(
         template=template,
         icon_name=icon_name,
         hidden=hidden,
+        metadata=metadata,
     )
 
     # Python 2 compatibility
@@ -161,13 +158,13 @@ def command(
 def parameter(
     _wrapped=None,  # type: Union[Callable, MethodType, Type]
     key=None,  # type: str
-    type=None,  # type: Optional[str]
+    type=None,  # type: Optional[Union[str, Type]]
     multi=None,  # type: Optional[bool]
     display_name=None,  # type: Optional[str]
     optional=None,  # type: Optional[bool]
     default=None,  # type: Optional[Any]
     description=None,  # type: Optional[str]
-    choices=None,  # type: Optional[Union[Dict, Iterable, str]]
+    choices=None,  # type: Optional[Union[Callable, Dict, Iterable, str]]
     parameters=None,  # type: Optional[List[Parameter]]
     nullable=None,  # type: Optional[bool]
     maximum=None,  # type: Optional[int]
@@ -279,7 +276,11 @@ def parameter(
 
 
 def parameters(*args, **kwargs):
-    """Decorator for specifying multiple Parameter definitions at once
+    """
+    .. deprecated:: 3.0
+        Will be removed in version 4.0. Please use ``@command`` instead.
+
+    Decorator for specifying multiple Parameter definitions at once
 
     This can be useful for commands which have a large number of complicated
     parameters but aren't good candidates for a Model.
@@ -439,12 +440,17 @@ def _initialize_command(method):
     cmd.name = _method_name(method)
     cmd.description = cmd.description or _method_docstring(method)
 
-    resolved_mod = _resolve_display_modifiers(
-        method, cmd.name, schema=cmd.schema, form=cmd.form, template=cmd.template
-    )
-    cmd.schema = resolved_mod["schema"]
-    cmd.form = resolved_mod["form"]
-    cmd.template = resolved_mod["template"]
+    try:
+        base_dir = os.path.dirname(inspect.getfile(method))
+
+        cmd.schema = resolve_schema(cmd.schema, base_dir=base_dir)
+        cmd.form = resolve_form(cmd.form, base_dir=base_dir)
+        cmd.template = resolve_template(cmd.template, base_dir=base_dir)
+    except PluginParamError as ex:
+        six.raise_from(
+            PluginParamError("Error initializing command '%s': %s" % (cmd.name, ex)),
+            ex,
+        )
 
     return cmd
 
@@ -491,77 +497,6 @@ def _method_docstring(method):
     return docstring.split("\n")[0] if docstring else None
 
 
-def _resolve_display_modifiers(
-    wrapped,  # type: MethodType
-    command_name,  # type: str
-    schema=None,  # type: Union[dict, str]
-    form=None,  # type: Union[dict, list, str]
-    template=None,  # type: str
-):
-    # type: (...) -> dict
-    """Parse display modifier parameter attributes
-
-    Returns:
-        Dictionary that fully describes a display specification
-    """
-
-    def _load_from_url(url):
-        response = requests.get(url)
-        if response.headers.get("content-type", "").lower() == "application/json":
-            return json.loads(response.text)
-        return response.text
-
-    def _load_from_path(path):
-        current_dir = os.path.dirname(inspect.getfile(wrapped))
-        file_path = os.path.abspath(os.path.join(current_dir, path))
-
-        with open(file_path, "r") as definition_file:
-            return definition_file.read()
-
-    resolved = {}
-
-    for key, value in {"schema": schema, "form": form, "template": template}.items():
-
-        if isinstance(value, six.string_types):
-            try:
-                if value.startswith("http"):
-                    resolved[key] = _load_from_url(value)
-
-                elif value.startswith("/") or value.startswith("."):
-                    loaded_value = _load_from_path(value)
-                    resolved[key] = (
-                        loaded_value if key == "template" else json.loads(loaded_value)
-                    )
-
-                elif key == "template":
-                    resolved[key] = value
-
-                else:
-                    raise PluginParamError(
-                        "%s specified for command '%s' was not a "
-                        "definition, file path, or URL" % (key, command_name)
-                    )
-            except Exception as ex:
-                raise PluginParamError(
-                    "Error reading %s definition from '%s' for command "
-                    "'%s': %s" % (key, value, command_name, ex)
-                )
-
-        elif value is None or (key in ["schema", "form"] and isinstance(value, dict)):
-            resolved[key] = value
-
-        elif key == "form" and isinstance(value, list):
-            resolved[key] = {"type": "fieldset", "items": value}
-
-        else:
-            raise PluginParamError(
-                "%s specified for command '%s' was not a definition, "
-                "file path, or URL" % (key, command_name)
-            )
-
-    return resolved
-
-
 def _sig_info(arg):
     # type: (InspectParameter) -> Tuple[Any, bool]
     """Get the default and optionality of a method argument
@@ -668,18 +603,20 @@ def _initialize_parameter(
     if param.key is None:
         raise PluginParamError("Attempted to create a parameter without a key")
 
-    param.type = _format_type(param.type)
-    param.choices = _format_choices(param.choices)
-
+    # Type and type info
     # Type info is where type specific information goes. For now, this is specific
     # to file types. See #289 for more details.
-    if param.type == "Bytes":
-        param.type_info = {"storage": "gridfs"}
+    param.type = _format_type(param.type)
+    param.type_info = param.type_info or {}
+    if param.type in Resolvable.TYPES:
+        param.type_info["storage"] = "gridfs"
 
-    # Nullifying default file parameters for safety
-    if param.type == "Base64":
+        # Also nullify default parameters for safety
         param.default = None
 
+    # Process the raw choices into a Choices object
+    param.choices = process_choices(param.choices)
+
     # Now deal with nested parameters
     if param.parameters or param.model:
         if param.model:
@@ -719,8 +656,6 @@ def _format_type(param_type):
         return "Boolean"
     elif param_type == dict:
         return "Dictionary"
-    elif str(param_type).lower() == "file":
-        return "Bytes"
     elif str(param_type).lower() == "datetime":
         return "DateTime"
     elif not param_type:
@@ -729,132 +664,6 @@ def _format_type(param_type):
         return str(param_type).title()
 
 
-def _format_choices(choices):
-    # type: (Union[dict, str, Iterable]) -> Optional[Choices]
-    """Parse choices definition
-
-    Args:
-        choices: Raw choices definition, usually from a decorator
-
-    Returns:
-        Choices: Dictionary that fully describes a choices specification
-    """
-
-    def determine_display(display_value):
-        if isinstance(display_value, six.string_types):
-            return "typeahead"
-
-        return "select" if len(display_value) <= 50 else "typeahead"
-
-    def determine_type(type_value):
-        if isinstance(type_value, six.string_types):
-            return "url" if type_value.startswith("http") else "command"
-
-        return "static"
-
-    if choices is None or isinstance(choices, Choices):
-        return choices
-
-    if isinstance(choices, dict):
-        if not choices.get("value"):
-            raise PluginParamError(
-                "No 'value' provided for choices. You must at least "
-                "provide valid values."
-            )
-
-        value = choices.get("value")
-        display = choices.get("display", determine_display(value))
-        choice_type = choices.get("type")
-        strict = choices.get("strict", True)
-
-        if choice_type is None:
-            choice_type = determine_type(value)
-        elif choice_type not in Choices.TYPES:
-            raise PluginParamError(
-                "Invalid choices type '%s' - Valid type options are %s"
-                % (choice_type, Choices.TYPES)
-            )
-        else:
-            if (
-                (
-                    choice_type == "command"
-                    and not isinstance(value, (six.string_types, dict))
-                )
-                or (choice_type == "url" and not isinstance(value, six.string_types))
-                or (choice_type == "static" and not isinstance(value, (list, dict)))
-            ):
-                allowed_types = {
-                    "command": "('string', 'dictionary')",
-                    "url": "('string')",
-                    "static": "('list', 'dictionary)",
-                }
-                raise PluginParamError(
-                    "Invalid choices value type '%s' - Valid value types for "
-                    "choice type '%s' are %s"
-                    % (type(value), choice_type, allowed_types[choice_type])
-                )
-
-        if display not in Choices.DISPLAYS:
-            raise PluginParamError(
-                "Invalid choices display '%s' - Valid display options are %s"
-                % (display, Choices.DISPLAYS)
-            )
-
-    elif isinstance(choices, str):
-        value = choices
-        display = determine_display(value)
-        choice_type = determine_type(value)
-        strict = True
-
-    else:
-        try:
-            # Assume some sort of iterable
-            value = list(choices)
-        except TypeError:
-            raise PluginParamError(
-                "Invalid 'choices': must be a string, dictionary, or iterable."
-            )
-
-        display = determine_display(value)
-        choice_type = determine_type(value)
-        strict = True
-
-    # Now parse out type-specific aspects
-    unparsed_value = ""
-    try:
-        if choice_type == "command":
-            if isinstance(value, six.string_types):
-                unparsed_value = value
-            else:
-                unparsed_value = value["command"]
-
-            details = parse(unparsed_value, parse_as="func")
-        elif choice_type == "url":
-            unparsed_value = value
-            details = parse(unparsed_value, parse_as="url")
-        else:
-            if isinstance(value, dict):
-                unparsed_value = choices.get("key_reference")
-                if unparsed_value is None:
-                    raise PluginParamError(
-                        "Specifying a static choices dictionary requires a "
-                        '"key_reference" field with a reference to another '
-                        'parameter ("key_reference": "${param_key}")'
-                    )
-
-                details = {"key_reference": parse(unparsed_value, parse_as="reference")}
-            else:
-                details = {}
-    except ParseError:
-        raise PluginParamError(
-            "Invalid choices definition - Unable to parse '%s'" % unparsed_value
-        )
-
-    return Choices(
-        type=choice_type, display=display, value=value, strict=strict, details=details
-    )
-
-
 def _initialize_parameters(parameter_list):
     # type: (Iterable[Parameter, object, dict]) -> List[Parameter]
     """Initialize Parameters from a list of parameter definitions
@@ -1048,6 +857,10 @@ system = client
 
 
 def command_registrar(*args, **kwargs):
+    """
+    .. deprecated: 3.0
+        Will be removed in 4.0. Use ``@system`` instead.
+    """
     _deprecate(
         "Looks like you're using the '@command_registrar' decorator. Heads up - this "
         "name will be removed in version 4.0, please use '@system' instead. Thanks!"
@@ -1056,6 +869,10 @@ def command_registrar(*args, **kwargs):
 
 
 def register(*args, **kwargs):
+    """
+    .. deprecated: 3.0
+        Will be removed in 4.0. Use ``@command`` instead.
+    """
     _deprecate(
         "Looks like you're using the '@register' decorator. Heads up - this name will "
         "be removed in version 4.0, please use '@command' instead. Thanks!"
@@ -1064,6 +881,10 @@ def register(*args, **kwargs):
 
 
 def plugin_param(*args, **kwargs):
+    """
+    .. deprecated: 3.0
+        Will be removed in 4.0. Use ``@parameter`` instead.
+    """
     _deprecate(
         "Looks like you're using the '@plugin_param' decorator. Heads up - this name "
         "will be removed in version 4.0, please use '@parameter' instead. Thanks!"
