@@ -34,6 +34,7 @@ __all__ = [
     "FileTrigger",
     "Garden",
     "Operation",
+    "Resolvable",
 ]
 
 
@@ -46,7 +47,7 @@ class Events(Enum):
     REQUEST_STARTED = 6
     REQUEST_UPDATED = 22
     REQUEST_COMPLETED = 7
-    REQUEST_CANCELED = 29
+    REQUEST_CANCELED = 42
     INSTANCE_INITIALIZED = 8
     INSTANCE_STARTED = 9
     INSTANCE_UPDATED = 23
@@ -81,6 +82,8 @@ class Events(Enum):
     RUNNER_REMOVED = 40
     JOB_UPDATED = 41
 
+    # Next: 43
+
 
 class BaseModel(object):
     schema = None
@@ -104,6 +107,7 @@ class Command(BaseModel):
         template=None,
         icon_name=None,
         hidden=False,
+        metadata=None,
     ):
         self.name = name
         self.description = description
@@ -115,6 +119,7 @@ class Command(BaseModel):
         self.template = template
         self.icon_name = icon_name
         self.hidden = hidden
+        self.metadata = metadata or {}
 
     def __str__(self):
         return self.name
@@ -273,7 +278,7 @@ class Parameter(BaseModel):
 
     def __init__(
         self,
-        key,
+        key=None,
         type=None,
         multi=None,
         display_name=None,
@@ -583,8 +588,16 @@ class RequestTemplate(BaseModel):
 class Request(RequestTemplate):
     schema = "RequestSchema"
 
-    STATUS_LIST = ("CREATED", "RECEIVED", "IN_PROGRESS", "CANCELED", "SUCCESS", "ERROR")
-    COMPLETED_STATUSES = ("CANCELED", "SUCCESS", "ERROR")
+    STATUS_LIST = (
+        "CREATED",
+        "RECEIVED",
+        "IN_PROGRESS",
+        "CANCELED",
+        "SUCCESS",
+        "ERROR",
+        "INVALID",
+    )
+    COMPLETED_STATUSES = ("CANCELED", "SUCCESS", "ERROR", "INVALID")
     COMMAND_TYPES = ("ACTION", "INFO", "EPHEMERAL", "ADMIN")
     OUTPUT_TYPES = ("STRING", "JSON", "XML", "HTML", "JS", "CSS")
 
@@ -701,6 +714,7 @@ class System(BaseModel):
         metadata=None,
         namespace=None,
         local=None,
+        template=None,
     ):
         self.name = name
         self.description = description
@@ -714,6 +728,7 @@ class System(BaseModel):
         self.metadata = metadata or {}
         self.namespace = namespace
         self.local = local
+        self.template = template
 
     def __str__(self):
         return "%s:%s-%s" % (self.namespace, self.name, self.version)
@@ -787,7 +802,10 @@ class System(BaseModel):
         return None
 
     def get_instance(self, name):
-        """DEPRECATED: Please use get_instance_by_name instead"""
+        """
+        .. deprecated::3.0
+           Will be removed in 4.0. Use ``get_instance_by_name`` instead
+        """
         _deprecate(
             "Heads up! This method is deprecated, please use get_instance_by_name"
         )
@@ -1115,6 +1133,7 @@ class Job(BaseModel):
         error_count=None,
         status=None,
         max_instances=None,
+        timeout=None,
     ):
         self.id = id
         self.name = name
@@ -1128,6 +1147,7 @@ class Job(BaseModel):
         self.error_count = error_count
         self.status = status
         self.max_instances = max_instances
+        self.timeout = timeout
 
     def __str__(self):
         return "%s: %s" % (self.name, self.id)
@@ -1463,3 +1483,27 @@ class Runner(BaseModel):
                 self.restart,
             )
         )
+
+
+class Resolvable(BaseModel):
+    schema = "ResolvableSchema"
+
+    # Resolvable parameter types
+    TYPES = ("Base64", "Bytes")
+
+    def __init__(self, id=None, type=None, storage=None, details=None):
+        self.id = id
+        self.type = type
+        self.storage = storage
+        self.details = details or {}
+
+    def __str__(self):
+        return "%s: %s %s" % (self.id, self.type, self.storage)
+
+    def __repr__(self):
+        return "<Resolvable: id=%s, type=%s, storage=%s, details=%s>" % (
+            self.id,
+            self.type,
+            self.storage,
+            self.details,
+        )
