@@ -10,11 +10,13 @@ import threading
 import appdirs
 from box import Box
 from packaging.version import Version
+from pathlib import Path
 from requests import ConnectionError as RequestsConnectionError
 
 import brewtils
 from brewtils.config import load_config
 from brewtils.decorators import _parse_client
+from brewtils.display import resolve_template
 from brewtils.errors import (
     ConflictError,
     DiscardMessageException,
@@ -32,12 +34,13 @@ from brewtils.request_handling import (
     RequestConsumer,
     RequestProcessor,
 )
-from brewtils.resolvers import build_resolver_map
+from brewtils.resolvers.manager import ResolutionManager
 from brewtils.rest.easy_client import EasyClient
 from brewtils.specification import _CONNECTION_SPEC
 
 # This is what enables request nesting to work easily
 request_context = threading.local()
+request_context.current_request = None
 
 # Global config, used to simplify BG client creation and sanity checks.
 CONFIG = Box(default_box=True)
@@ -350,7 +353,6 @@ class Plugin(object):
 
         self._system = self._initialize_system()
         self._instance = self._initialize_instance()
-        self._admin_processor, self._request_processor = self._initialize_processors()
 
         if self._config.working_directory is None:
             app_parts = [self._system.name, self._instance.name]
@@ -361,7 +363,12 @@ class Plugin(object):
                 appname=os.path.join(*app_parts), version=self._system.version
             )
 
-        self._logger.debug("Starting up processors")
+            workdir = Path(self._config.working_directory)
+            if not workdir.exists():
+                workdir.mkdir(parents=True)
+
+        self._logger.debug("Initializing and starting processors")
+        self._admin_processor, self._request_processor = self._initialize_processors()
         self._admin_processor.startup()
         self._request_processor.startup()
 
@@ -403,7 +410,6 @@ class Plugin(object):
 
         Returns:
             None
-
         """
         if self._custom_logger:
             self._logger.debug("Skipping logging init: custom logger detected")
@@ -457,11 +463,13 @@ class Plugin(object):
 
         Raises:
             PluginValidationError: Unable to find or create a System for this Plugin
-
         """
         # Make sure that the system is actually valid before trying anything
         self._validate_system()
 
+        # Do any necessary template resolution
+        self._system.template = resolve_template(self._system.template)
+
         existing_system = self._ez_client.find_unique_system(
             name=self._system.name,
             version=self._system.version,
@@ -494,6 +502,7 @@ class Plugin(object):
             "description": self._system.description,
             "display_name": self._system.display_name,
             "icon_name": self._system.icon_name,
+            "template": self._system.template,
         }
 
         # And if this particular instance doesn't exist we want to add it
@@ -552,23 +561,32 @@ class Plugin(object):
             **common_args
         )
 
+        # Both RequestProcessors need an updater
+        updater = HTTPRequestUpdater(
+            self._ez_client,
+            self._shutdown_event,
+            max_attempts=self._config.max_attempts,
+            max_timeout=self._config.max_timeout,
+            starting_timeout=self._config.starting_timeout,
+        )
+
         # Finally, create the actual RequestProcessors
         admin_processor = AdminProcessor(
             target=self,
-            updater=HTTPRequestUpdater(self._ez_client, self._shutdown_event),
+            updater=updater,
             consumer=admin_consumer,
             plugin_name=self.unique_name,
             max_workers=1,
         )
         request_processor = RequestProcessor(
             target=self._client,
-            updater=HTTPRequestUpdater(self._ez_client, self._shutdown_event),
+            updater=updater,
             consumer=request_consumer,
             validation_funcs=[self._correct_system, self._is_running],
             plugin_name=self.unique_name,
             max_workers=self._config.max_concurrent,
-            working_directory=self._config.working_directory,
-            resolvers=build_resolver_map(self._ez_client),
+            resolver=ResolutionManager(easy_client=self._ez_client),
+            system=self._system,
         )
 
         return admin_processor, request_processor
@@ -761,6 +779,7 @@ class Plugin(object):
             "max_instances",
             "metadata",
             "namespace",
+            "template",
         }
 
         if system:
@@ -792,6 +811,7 @@ class Plugin(object):
                 max_instances=self._config.max_instances,
                 icon_name=self._config.icon_name,
                 display_name=self._config.display_name,
+                template=self._config.template,
             )
 
         return system
@@ -821,51 +841,111 @@ class Plugin(object):
     # These are provided for backward-compatibility
     @property
     def bg_host(self):
+        """
+        .. deprecated:: 3.0
+           bg_host is now in ``_config`` (``plugin._config.bg_host``)
+
+        Provided for backward-comptibility
+        """
         _deprecate("bg_host is now in _config (plugin._config.bg_host)")
         return self._config.bg_host
 
     @property
     def bg_port(self):
+        """
+        .. deprecated:: 3.0
+           bg_port is now in _config (``plugin._config.bg_port``)
+
+        Provided for backward-comptibility
+        """
         _deprecate("bg_port is now in _config (plugin._config.bg_port)")
         return self._config.bg_port
 
     @property
     def ssl_enabled(self):
+        """
+        .. deprecated:: 3.0
+           ssl_enabled is now in ``_config`` (``plugin._config.ssl_enabled``)
+
+        Provided for backward-comptibility
+        """
         _deprecate("ssl_enabled is now in _config (plugin._config.ssl_enabled)")
         return self._config.ssl_enabled
 
     @property
     def ca_cert(self):
+        """
+        .. deprecated:: 3.0
+           ca_cert is now in ``_config`` (``plugin._config.ca_cert``)
+
+        Provided for backward-comptibility
+        """
         _deprecate("ca_cert is now in _config (plugin._config.ca_cert)")
         return self._config.ca_cert
 
     @property
     def client_cert(self):
+        """
+        .. deprecated:: 3.0
+           client_cert is now in ``_config`` (``plugin._config.client_cert``)
+
+        Provided for backward-comptibility
+        """
         _deprecate("client_cert is now in _config (plugin._config.client_cert)")
         return self._config.client_cert
 
     @property
     def bg_url_prefix(self):
+        """
+        .. deprecated:: 3.0
+           bg_url_prefix is now in ``_config`` (``plugin._config.bg_url_prefix``)
+
+        Provided for backward-comptibility
+        """
         _deprecate("bg_url_prefix is now in _config (plugin._config.bg_url_prefix)")
         return self._config.bg_url_prefix
 
     @property
     def ca_verify(self):
+        """
+        .. deprecated:: 3.0
+           ca_verify is now in ``_config`` (``plugin._config.ca_verify``)
+
+        Provided for backward-comptibility
+        """
         _deprecate("ca_verify is now in _config (plugin._config.ca_verify)")
         return self._config.ca_verify
 
     @property
     def max_attempts(self):
+        """
+        .. deprecated:: 3.0
+           max_attempts is now in ``_config`` (``plugin._config.max_attempts``)
+
+        Provided for backward-comptibility
+        """
         _deprecate("max_attempts is now in _config (plugin._config.max_attempts)")
         return self._config.max_attempts
 
     @property
     def max_timeout(self):
+        """
+        .. deprecated:: 3.0
+           max_timeout is now in ``_config`` (``plugin._config.max_timeout``)
+
+        Provided for backward-comptibility
+        """
         _deprecate("max_timeout has moved into _config (plugin._config.max_timeout)")
         return self._config.max_timeout
 
     @property
     def starting_timeout(self):
+        """
+        .. deprecated:: 3.0
+           starting_timeout is now in ``_config`` (``plugin._config.starting_timeout``)
+
+        Provided for backward-comptibility
+        """
         _deprecate(
             "starting_timeout is now in _config (plugin._config.starting_timeout)"
         )
@@ -873,42 +953,91 @@ class Plugin(object):
 
     @property
     def max_concurrent(self):
+        """
+        .. deprecated:: 3.0
+           max_concurrent is now in ``_config`` (``plugin._config.max_concurrent``)
+
+        Provided for backward-comptibility
+        """
         _deprecate("max_concurrent is now in _config (plugin._config.max_concurrent)")
         return self._config.max_concurrent
 
     @property
     def instance_name(self):
+        """
+        .. deprecated:: 3.0
+           instance_name is now in ``_config`` (``plugin._config.instance_name``)
+
+        Provided for backward-comptibility
+        """
         _deprecate("instance_name is now in _config (plugin._config.instance_name)")
         return self._config.instance_name
 
     @property
     def connection_parameters(self):
+        """
+        .. deprecated:: 3.0
+           connection_parameters has been removed. Please use ``_config``
+
+        Provided for backward-comptibility
+        """
         _deprecate("connection_parameters attribute was removed, please use '_config'")
         return {key: self._config[key] for key in _CONNECTION_SPEC}
 
     @property
     def metadata(self):
+        """
+        .. deprecated:: 3.0
+           metadata is now part of the ``system`` attribute (``plugin.system.metadata``)
+
+        Provided for backward-comptibility
+        """
         _deprecate("metadata is a part of the system attribute (plugin.system.metadata")
         return self._system.metadata
 
     @property
     def bm_client(self):
+        """
+        .. deprecated:: 3.0
+            bm_client attribute has been renamed to ``_ez_client``.
+
+        Provided for backward-comptibility
+        """
         _deprecate("bm_client attribute has been renamed to _ez_client")
         return self._ez_client
 
     @property
     def shutdown_event(self):
+        """
+        .. deprecated:: 3.0
+            shutdown_event attribute has been renamed to ``_shutdown_event``.
+
+        Provided for backward-comptibility
+        """
         _deprecate("shutdown_event attribute has been renamed to _shutdown_event")
         return self._shutdown_event
 
     @property
     def logger(self):
+        """
+        .. deprecated:: 3.0
+            logger attribute has been renamed to ``_logger``.
+
+        Provided for backward-comptibility
+        """
         _deprecate("logger attribute has been renamed to _logger")
         return self._logger
 
 
 # Alias old names
 class PluginBase(Plugin):
+    """
+    .. deprecated:: 3.0
+        Will be removed in version 4.0. Please use ``Plugin`` instead.
+
+    ``Plugin`` alias Provided for backward-comptibility
+    """
+
     def __init__(self, *args, **kwargs):
         _deprecate(
             "Looks like you're creating a 'PluginBase'. Heads up - this name will be "
@@ -918,6 +1047,13 @@ class PluginBase(Plugin):
 
 
 class RemotePlugin(Plugin):
+    """
+    .. deprecated:: 3.0
+        Will be removed in version 4.0. Please use ``Plugin`` instead.
+
+    ``Plugin`` alias Provided for backward-comptibility
+    """
+
     def __init__(self, *args, **kwargs):
         _deprecate(
             "Looks like you're creating a 'RemotePlugin'. Heads up - this name will be "
