@@ -73,6 +73,7 @@ class TimeoutAdapter(HTTPAdapter):
         super(TimeoutAdapter, self).__init__(**kwargs)
 
     def send(self, *args, **kwargs):
+        """Sends PreparedRequest object with specified timeout."""
         kwargs["timeout"] = kwargs.get("timeout") or self.timeout
         return super(TimeoutAdapter, self).send(*args, **kwargs)
 
@@ -123,6 +124,12 @@ class RestClient(object):
         # Configure the session to use when making requests
         self.session = Session()
 
+        if self._config.proxy:
+            if self._config.ssl_enabled:
+                self.session.proxies.update({"https": self._config.proxy})
+            else:
+                self.session.proxies.update({"http": self._config.proxy})
+
         # This is what Requests is expecting
         if self._config.client_key:
             self.session.cert = (self._config.client_cert, self._config.client_key)
@@ -169,8 +176,10 @@ class RestClient(object):
             # Deprecated
             self.logging_config_url = self.base_url + "api/v1/config/logging/"
 
+            # Beta
             self.event_url = self.base_url + "api/vbeta/events/"
-            self.file_url = self.base_url + "api/v1/files/"
+            self.chunk_url = self.base_url + "api/vbeta/chunks/"
+            self.file_url = self.base_url + "api/vbeta/file/"
         else:
             raise ValueError("Invalid Beer-garden API version: %s" % self.api_version)
 
@@ -186,7 +195,7 @@ class RestClient(object):
         4. the global configuration (brewtils.plugin.CONFIG)
 
         Args:
-            args: DEPRECATED - host and port
+            args (deprecated): host and port
             kwargs: Standard connection arguments to be used
 
         Returns:
@@ -222,7 +231,7 @@ class RestClient(object):
         """Determine if a connection to the Beer-garden server is possible
 
         Args:
-            kwargs: Keyword arguments to pass to Requests session call
+            **kwargs: Keyword arguments to pass to Requests session call
 
         Returns:
             A bool indicating if the connection attempt was successful. Will
@@ -249,6 +258,9 @@ class RestClient(object):
         # type: (**Any) -> Response
         """Perform a GET to the version URL
 
+        Args:
+            **kwargs (deprecated): Unused. Accepted for compatibility.
+
         Returns:
             Requests Response object
         """
@@ -265,6 +277,9 @@ class RestClient(object):
         # type: (**Any) -> Response
         """Perform a GET to the config URL
 
+        Args:
+            **kwargs (deprecated): Unused. Accepted for compatibility.
+
         Returns:
             Requests Response object
         """
@@ -282,7 +297,7 @@ class RestClient(object):
         """Perform a GET to the logging config URL
 
         Args:
-            kwargs: Query parameters to be used in the GET request
+            **kwargs: Query parameters to be used in the GET request
 
         Returns:
             Requests Response object
@@ -295,7 +310,7 @@ class RestClient(object):
         """Perform a GET on the System collection URL
 
         Args:
-            kwargs: Query parameters to be used in the GET request
+            **kwargs: Query parameters to be used in the GET request
 
         Returns:
             Requests Response object
@@ -309,7 +324,7 @@ class RestClient(object):
 
         Args:
             system_id: System ID
-            kwargs: Query parameters to be used in the GET request
+            **kwargs: Query parameters to be used in the GET request
 
         Returns:
             Requests Response object
@@ -433,7 +448,7 @@ class RestClient(object):
         """Performs a GET on the Requests URL
 
         Args:
-            kwargs: Query parameters to be used in the GET request
+            **kwargs: Query parameters to be used in the GET request
 
         Returns:
             Requests Response object
@@ -460,7 +475,7 @@ class RestClient(object):
 
         Args:
             payload: New Request definition
-            kwargs: Extra request parameters
+            **kwargs: Extra request parameters
 
         Keyword Args:
             blocking: Wait for request to complete
@@ -547,7 +562,7 @@ class RestClient(object):
         """Performs a GET on the Jobs URL.
 
         Args:
-            kwargs: Query parameters to be used in the GET request
+            **kwargs: Query parameters to be used in the GET request
 
         Returns:
             Requests Response object
@@ -616,29 +631,69 @@ class RestClient(object):
 
         Args:
             file_id: File ID
-            kwargs: Query parameters to be used in the GET request
+            **kwargs: Query parameters to be used in the GET request
 
         Returns:
             Requests Response object
         """
-        return self.session.get(self.file_url + "?file_id=" + file_id, **kwargs)
+        return self.session.get(self.file_url + file_id, **kwargs)
 
     @enable_auth
-    def delete_file(self, file_id, **kwargs):
+    def post_file(self, data):
+        # type: (bytes) -> Response
+        """Performs a PUT on the file URL
+
+        Args:
+            data: Data bytes
+
+        Returns:
+            A Requests Response object
+        """
+        return self.session.post(self.file_url, data=data)
+
+    @enable_auth
+    def delete_file(self, file_id):
+        # type: (str) -> Response
+        """Performs a DELETE on the specific File URL
+
+        Args:
+            file_id: File ID
+
+        Returns:
+            Requests Response object
+        """
+        return self.session.delete(self.file_url + file_id)
+
+    @enable_auth
+    def get_chunked_file(self, file_id, **kwargs):
         # type: (str, **Any) -> Response
         """Performs a GET on the specific File URL
 
         Args:
             file_id: File ID
-            kwargs: Query parameters to be used in the GET request
+            **kwargs: Query parameters to be used in the GET request
 
         Returns:
             Requests Response object
         """
-        return self.session.delete(self.file_url + "?file_id=" + file_id, **kwargs)
+        return self.session.get(self.chunk_url + "?file_id=" + file_id, **kwargs)
 
     @enable_auth
-    def post_file(self, fd, file_params, current_position=0):
+    def delete_chunked_file(self, file_id, **kwargs):
+        # type: (str, **Any) -> Response
+        """Performs a GET on the specific File URL
+
+        Args:
+            file_id: File ID
+            **kwargs: Query parameters to be used in the GET request
+
+        Returns:
+            Requests Response object
+        """
+        return self.session.delete(self.chunk_url + "?file_id=" + file_id, **kwargs)
+
+    @enable_auth
+    def post_chunked_file(self, fd, file_params, current_position=0):
         """Performs a POST on the file URL.
 
         Args:
@@ -654,57 +709,60 @@ class RestClient(object):
         # read on each of the files, that method fails with a 4XX, we then
         # authenticate and try again, only to post an empty file.
         fd.seek(current_position)
-        # Establish a top-level file handle first
-        result = self.session.get(self.file_url + "id/", params=file_params)
-        if result.ok:
-            file_id = result.json()["file_id"]
-            offset = 0
-            retry = 0
-            current_cursor = 0
-            # Break up the file into chunks and send them
-            while True:
-                current_cursor = fd.tell()
-                data = fd.read(file_params["chunk_size"])
-                if not data:
-                    break
-                if type(data) != bytes:
-                    data = bytes(data, "utf-8")
-                data = b64encode(data)
-                chunk_result = self.session.post(
-                    self.file_url + "?file_id=" + file_id,
-                    json={"data": data, "offset": offset},
-                )
 
-                # Allow the system to try to resend the chunk a couple of
-                # times before giving up.
-                if chunk_result.ok:
-                    offset += 1
-                    retry = 0
-                elif retry < 3:
-                    fd.seek(current_cursor)
-                    retry += 1
-                else:
-                    raise RuntimeError(
-                        "Could not send chunk %s, ran out of retries" % offset
-                    )
-        else:
+        # Establish a top-level file handle first
+        result = self.session.get(self.chunk_url + "id/", params=file_params)
+
+        if not result.ok:
             raise RuntimeError("Could not request file ID for file %s" % fd.name)
 
+        file_id = result.json()["details"]["file_id"]
+        offset = 0
+        retry = 0
+
+        # Break up the file into chunks and send them
+        while True:
+            current_cursor = fd.tell()
+            data = fd.read(file_params["chunk_size"])
+            if not data:
+                break
+            if type(data) != bytes:
+                data = bytes(data, "utf-8")
+            data = b64encode(data)
+            chunk_result = self.session.post(
+                self.chunk_url + "?file_id=" + file_id,
+                json={"data": data, "offset": offset},
+            )
+
+            # Allow the system to try to resend the chunk a couple of
+            # times before giving up.
+            if chunk_result.ok:
+                offset += 1
+                retry = 0
+            elif retry < 3:
+                fd.seek(current_cursor)
+                retry += 1
+            else:
+                raise RuntimeError(
+                    "Could not send chunk %s, ran out of retries" % offset
+                )
+
         return result
 
     @enable_auth
-    def post_forward(self, payload):
-        # type: (str) -> Response
+    def post_forward(self, payload, **kwargs):
+        # type: (str, **Any) -> Response
         """Performs a POST on the Forward URL
 
         Args:
             payload: The operation to be executed
+            **kwargs: Keyword arguments to pass to Requests session call
 
         Returns:
             The API response
         """
         return self.session.post(
-            self.forward_url, data=payload, headers=self.JSON_HEADERS
+            self.forward_url, data=payload, headers=self.JSON_HEADERS, params=kwargs
         )
 
     @enable_auth
