@@ -187,6 +187,7 @@ class CommandSchema(BaseSchema):
     template = fields.Str(allow_none=True)
     icon_name = fields.Str(allow_none=True)
     hidden = fields.Boolean(allow_none=True)
+    metadata = fields.Dict(allow_none=True)
 
 
 class InstanceSchema(BaseSchema):
@@ -214,6 +215,7 @@ class SystemSchema(BaseSchema):
     metadata = fields.Dict(allow_none=True)
     namespace = fields.Str(allow_none=True)
     local = fields.Bool(allow_none=True)
+    template = fields.Str(allow_none=True)
 
 
 class RequestFileSchema(BaseSchema):
@@ -466,6 +468,7 @@ class JobSchema(BaseSchema):
     error_count = fields.Int(allow_none=True)
     status = fields.Str(allow_none=True)
     max_instances = fields.Int(allow_none=True)
+    timeout = fields.Int(allow_none=True)
 
 
 class OperationSchema(BaseSchema):
@@ -490,6 +493,13 @@ class RunnerSchema(BaseSchema):
     restart = fields.Boolean(allow_none=True)
 
 
+class ResolvableSchema(BaseSchema):
+    id = fields.Str(allow_none=True)
+    type = fields.Str(allow_none=True)
+    storage = fields.Str(allow_none=True)
+    details = fields.Dict(allow_none=True)
+
+
 model_schema_map.update(
     {
         "Choices": ChoicesSchema,
@@ -518,6 +528,7 @@ model_schema_map.update(
         "System": SystemSchema,
         "Operation": OperationSchema,
         "Runner": RunnerSchema,
+        "Resolvable": ResolvableSchema,
         # Compatibility for the Job trigger types
         "interval": IntervalTriggerSchema,
         "date": DateTriggerSchema,
