@@ -25,6 +25,7 @@ from brewtils.models import (
     Request,
     RequestFile,
     RequestTemplate,
+    Resolvable,
     Role,
     Runner,
     System,
@@ -168,6 +169,7 @@ def command_dict(parameter_dict, system_id):
         "form": {},
         "template": "<html></html>",
         "icon_name": "icon!",
+        "metadata": {"meta": "data"},
     }
 
 
@@ -219,7 +221,7 @@ def instance_dict(ts_epoch):
             "url": "amqp://guest:guest@localhost:5672",
         },
         "status_info": {"heartbeat": ts_epoch},
-        "metadata": {},
+        "metadata": {"meta": "data"},
     }
 
 
@@ -247,6 +249,7 @@ def system_dict(instance_dict, command_dict, command_dict_2, system_id):
         "metadata": {"some": "stuff"},
         "namespace": "ns",
         "local": True,
+        "template": "<html>template</html>",
     }
 
 
@@ -259,6 +262,16 @@ def bg_system(system_dict, bg_instance, bg_command, bg_command_2):
     return System(**dict_copy)
 
 
+@pytest.fixture
+def bg_system_2(system_dict, bg_instance, bg_command, bg_command_2):
+    """A system with a different version."""
+    dict_copy = copy.deepcopy(system_dict)
+    dict_copy["version"] = "2.0.0"
+    dict_copy["instances"] = [bg_instance]
+    dict_copy["commands"] = [bg_command, bg_command_2]
+    return System(**dict_copy)
+
+
 @pytest.fixture
 def child_request_dict(ts_epoch):
     """A child request represented as a dictionary."""
@@ -540,6 +553,7 @@ def job_dict(ts_epoch, request_template_dict, date_trigger_dict):
         "error_count": 0,
         "status": "RUNNING",
         "max_instances": 3,
+        "timeout": 30,
     }
 
 
@@ -737,3 +751,34 @@ def runner_dict(instance_dict):
 def bg_runner(runner_dict):
     """A runner as a model."""
     return Runner(**runner_dict)
+
+
+@pytest.fixture
+def resolvable_dict():
+    """A resolvable as a dictionary."""
+    return {
+        "id": "60996b9dc021bf0d4add8b67",
+        "type": "bytes",
+        "storage": "gridfs",
+        "details": {"random": "detail"},
+    }
+
+
+@pytest.fixture
+def bg_resolvable(resolvable_dict):
+    return Resolvable(**resolvable_dict)
+
+
+@pytest.fixture
+def resolvable_chunk_dict():
+    """A resolvable as a dictionary."""
+    return {
+        "type": "base64",
+        "storage": "gridfs",
+        "details": {"file_id": "60996b9dc021bf0d4add8b67"},
+    }
+
+
+@pytest.fixture
+def bg_resolvable_chunk(resolvable_chunk_dict):
+    return Resolvable(**resolvable_chunk_dict)
